library(dplyr)
library(plotrix) #for the standard error function
library(segmented)
library(broom) #tidy
setwd('~/Box Sync/Antarctica/Bravo 134 2015-2016/Loligo/CTmax')

dat = read.csv('master_CTmax_20160119.csv')

dat$temp_reciprocal = 1/(dat$temp+273.16)
dat$logResp = log10(dat$umol_per_hour_indiv_corr)
dat$logDryWt = log10(dat$dry_weight)

# do weight coefficients change with temperature?
dat$temp_f = as.factor(dat$temp)
# temp_scaling = aov(logResp~logDryWt * temp_f, data = dat)
# summary(temp_scaling)
# ...no, they do not! on to find a common coefficient: 

# get scaling coefficient
weightCoef = lm(logResp ~ logDryWt, data = dat) %>%
  tidy() %>% 
  .$estimate %>% .[2]

#get mean mass:
mean_drywt = mean(dat$dry_weight, na.rm = TRUE)

# get resp scaled to mg:
dat$resp_by_mg_dry = dat$umol_per_hour_indiv_corr / dat$dry_weight
  

#apply weight standardization:
dat$resp_std =  dat$resp_by_mg_dry * (dat$dry_weight/mean_drywt)^(1-weightCoef)
  
### stats

#anova for different temps
anova_temp = aov(resp_std~temp_f, data = dat)
summary(anova_temp)
TukeyHSD(anova_temp)
###

#make smaller summary table for mean and standard error for mass-corrected.
dat_sum = dat%>%
  ungroup() %>%
  dplyr::group_by(temp) %>%
  dplyr::summarize(resp_norm = mean(resp_std, na.rm = TRUE), 
            std.error = std.error(resp_std), 
            temp_reciprocal = mean(temp_reciprocal))%>%
  ungroup()

#make smaller summary table for mean and standard error per individual.

dat_sum2 = dat%>%
  dplyr::group_by(temp) %>%
  dplyr::summarize(resp_norm = mean(resp_std, na.rm = TRUE), 
            std.error = std.error(resp_std))


###############33
#### Normal plot of temperature and respiration: 

plot(jitter(dat$temp, .1), dat$resp_std*1000, 
     pch = 20, col = 'grey', 
     xlab = 'Temperature (˚C)', ylab = 'Respiration (nmol/hr/indiv)'
)
     # main = 'CTmax' )
lines(dat_sum2$temp, dat_sum2$resp_norm*1000, lty= 2)

arrows(dat_sum2$temp, #xHigh
       ((dat_sum2$resp_norm+dat_sum2$std.error)*1000), #yHigh
       dat_sum$temp, #xLow
       ((dat_sum2$resp_norm-dat_sum2$std.error)*1000), 
       angle = 90, length = 0.1, code = 3) #yLow
##################'

ctmax = ggplot(dat, aes(temp_reciprocal, resp_std*1000))+geom_point(color = 'darkgrey')+
    scale_y_log10(name = expression(paste('respiration ( ',nM,' ',hr^-1,' ',indiv^-1,' )')),
      breaks = c(1:7)*10)+
  scale_x_continuous(name = expression(paste('T ( ',degree,'C ), plotted as ', T^  -1, '( K )')), 
    breaks = dat_sum$temp_reciprocal, labels = dat_sum$temp)+
  geom_line(data = dat_sum, aes(y = resp_norm*1000), linetype = 2)+
  geom_errorbar(data = dat_sum, aes(ymin = (resp_norm-std.error)*1000,
    ymax = (resp_norm+std.error)*1000, y = resp_norm*1000), width = .000005)


plotTheme(ctmax)


ggsave('~/Dropbox/Manuscripts/accepted/B134.Loligo/figures/final/fig3_ctmax.tiff', 
  width = 6, height = 4, units = 'in', dpi = 300)


# #boxplot(dat$umol_per_hour_normalized ~ dat$temp_reciprocal)
# dev.off()
# pdf('~/Desktop/CTmax_figure.pdf',
#       width = 7, height = 5)
# 
# plot(jitter(dat$temp_reciprocal, 0.1), log(dat$resp_std)*1000, 
#        pch = 20, col = 'grey',
#      
#      xlab = expression(paste('T ( ',degree,'C ), plotted as ', T^ -1, '( K )')),
#      ylab = expression(paste('respiration ( ',nM,' ',hr^-1,' ',indiv^-1,' )')),
#      yaxt = 'n', xaxt="n")
#      # ylim = c(-7000, -4500))
#      
# lines(dat_sum$temp_reciprocal, log(dat_sum$resp_norm)*1000, 
# 
#      lty= 2)
# arrows(dat_sum$temp_reciprocal, #xHigh
#        log(dat_sum$resp_norm+dat_sum$std.error)*1000, #yHigh
#        dat_sum$temp_reciprocal, #xLow
#        log(dat_sum$resp_norm-dat_sum$std.error)*1000, 
#        angle = 90, length = 0.1, code = 3) #yLow
# 
# axis(1, at = dat_sum$temp_reciprocal, labels = dat_sum$temp)
# 
# yticks = seq(from = 0.01, to = 0.1, by = .01)
# # axis(2)
# axis(2, at = log(yticks)*1000,
#      labels = yticks*1000)
#  dev.off()



#####
#http://www.r-bloggers.com/r-for-ecologists-putting-together-a-piecewise-regression/
dat = dat[complete.cases(dat),]  
dat_resp = log(dat$resp_std)*1000   
dat_temp = dat$temp_reciprocal  
lin.mod <- lm( dat_resp ~ dat_temp) 
segmented.mod <- segmented(lin.mod, seg.Z = ~dat_temp, psi=.0035)
plot(dat_temp, dat_resp, pch = 20)
plot(segmented.mod, add = T)

