# This is the survival analysis for the loligo manuscript - limacina 2015

library(plyr)
library(tidyverse)
library(survival)
library(survminer)


dat = read.csv('./data/survival_raw.csv')

# divide data into "censored" (ones that survived) and "dead" (obv. ones that didn't make it):

dat$day = as.numeric(substr(dat$Day.number, 2,4))
dat$treat = substr(dat$Tank, 1,1)
dat$replicate = as.numeric(substr(dat$Tank, 2,2))

dat.dead = dat[complete.cases(dat$Dead.on.day),]
dat.censored = dat[!complete.cases(dat$Dead.on.day),]

#get rid of NA columns
dat.dead = dat.dead[, !apply(is.na(dat.dead), 2, all)]
dat.censored = dat.censored[, !apply(is.na(dat.censored), 2, all)]

#######do dead ones first . we want to make a new row for each pteropod. 

#first get rid of days/tanks in day.dead that don't have any dead guys: 
dat.dead = dat.dead[(dat.dead$Dead.on.day>0),]


# I think you can do this with apply but we're going to do it with ddply using unique markers: 

dat.dead$rownames = rownames(dat.dead)

dat.dead.melt = plyr::ddply(dat.dead, 'rownames', function(x){
  return(x[rep(1, x$Dead.on.day),])
  })

#status = dead = 2
dat.dead.melt$status = 2

#######next do censored. These are ones that are at day 14, and were alive at the end. 

dat.censored$rownames = rownames(dat.censored)

dat.censored.melt = plyr::ddply(dat.censored, 'rownames', function(x){
  return(x[rep(1, x$alive.at.end),])
})

#censored = 1
dat.censored.melt$status = 1

##### Combine two dataframes 
dat.melt = rbind( dplyr::select(dat.dead.melt, Tank, day, treat, replicate, status),
  dplyr::select(dat.censored.melt, Tank, day, treat, replicate, status))


res.cox = coxph(Surv(day,status)~treat, data = dat.melt)
res.cox
summary(res.cox)


res.cox = survfit(Surv(day,status)~treat, data = dat.melt)
res.cox
summary(res.cox)
ggsurvplot(res.cox,
  pval = TRUE, conf.int = TRUE,
  risk.table = TRUE, # Add risk table
  risk.table.col = "strata", # Change risk table color by groups
  linetype = "strata", # Change line type by groups
  surv.median.line = "hv", # Specify median survival
  ggtheme = theme_bw())
